/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // kolfui.rc
  0x0,0x0,0x2,0x8,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x3e,0x6,0xf5,0xf,0x0,0xe6,0x16,0x45,0x1e,0x40,0x73,0x1e,
  0xb5,0x36,0x4b,0xb0,0x99,0x16,0x50,0xf9,0x61,0xab,0xde,0x93,0x39,0x1c,0x31,0x63,
  0xe9,0x62,0x14,0x3,0x7b,0x5b,0xc,0xc3,0x8,0x1b,0x11,0x3f,0x0,0x3e,0x0,0x3b,
  0x0,0x9b,0xf6,0x6f,0xee,0xeb,0xa5,0xdf,0xe0,0xf4,0x1,0xbf,0xcd,0xc0,0xb2,0xac,
  0xd6,0x12,0x15,0xa5,0x13,0x5b,0x7c,0x1b,0xa0,0x87,0x69,0xa4,0x6f,0xd8,0x82,0xa9,
  0x6d,0x28,0x56,0x18,0x3d,0x12,0x83,0x21,0x4,0x8f,0x8a,0x85,0x2d,0x60,0xc7,0xe7,
  0xae,0x19,0x62,0x84,0x41,0x81,0x2d,0xda,0xe3,0x4f,0xe6,0x40,0x92,0xba,0x18,0x51,
  0xd5,0x33,0x4b,0x7d,0xfa,0xdf,0x6,0x27,0x53,0x98,0xd7,0x5c,0x55,0xb,0x31,0x67,
  0xdf,0x35,0x98,0x5a,0x38,0xd7,0x51,0x9b,0x27,0x11,0xe0,0x91,0xd8,0xfb,0x6b,0x0,
  0x3d,0xed,0x91,0xae,0x73,0xc9,0x27,0xe2,0xb3,0xeb,0x28,0x58,0x8a,0x27,0x47,0x91,
  0x4c,0x2e,0xad,0x40,0x20,0x18,0xe,0x56,0xfc,0x2b,0xd1,0x62,0x85,0x1,0x1a,0xe,
  0xcf,0xea,0xe2,0x9e,0x1c,0x8d,0xd6,0x3b,0x4,0xe3,0x9d,0x95,0x95,0xbf,0xae,0xae,
  0xe9,0x68,0xd1,0xb9,0x94,0xf2,0xf3,0x9c,0xcb,0xd2,0x59,0xdc,0xd3,0xe9,0xce,0xad,
  0x98,0x2,0x3b,0xd2,0xf8,0xb8,0x45,0x2c,0x15,0x15,0xb5,0x1,0x8f,0x48,0xf4,0x62,
  0x1a,0x49,0x9f,0x5a,0xf4,0xb3,0xba,0xa3,0x1,0x8f,0x14,0x2b,0x6c,0xd1,0x23,0xb5,
  0xc8,0xe2,0xc6,0x30,0xb5,0xb0,0xe3,0x52,0xd2,0xbd,0x22,0x37,0x56,0x5a,0x49,0x96,
  0xb2,0xc1,0x32,0xb3,0xcd,0xaf,0xab,0x7f,0x47,0xc9,0x2f,0x56,0x48,0x6b,0xf5,0xd8,
  0xf5,0x72,0xde,0xb6,0xaf,0x4e,0xf1,0xb3,0xa7,0xfc,0xaf,0x97,0xfe,0xca,0x9f,0x31,
  0x62,0xa0,0xd1,0x8d,0x63,0x14,0x49,0x93,0xd4,0xac,0x33,0x6,0x30,0x84,0x10,0x4,
  0x19,0x95,0x7,0xc2,0x65,0x42,0x52,0x6c,0x8e,0x10,0x9c,0xa2,0x6f,0x41,0x4e,0xea,
  0x2,0x25,0xdb,0x16,0x60,0x8a,0x40,0xa0,0x1b,0xeb,0x96,0x32,0x7b,0x5f,0xe6,0x19,
  0x10,0x2,0x50,0x50,0xca,0x64,0x6b,0xd8,0x77,0x7,0x15,0x98,0x9b,0x69,0xc0,0x2b,
  0x14,0x90,0x41,0xba,0x42,0xf9,0xc4,0x8e,0x63,0x15,0xbe,0x2e,0x14,0x0,0x95,0x1f,
  0xaa,0xd8,0xb4,0x21,0x51,0x29,0x74,0x54,0x2a,0x57,0x7,0xd2,0x90,0xb2,0xc4,0x29,
  0x48,0xd2,0x7d,0xa2,0x36,0xb,0x10,0x2e,0xc0,0x9e,0x8b,0xf,0x1b,0x8e,0x63,0x1e,
  0x96,0x18,0x6e,0xb2,0x64,0x18,0x3a,0xbb,0x43,0x22,0x1a,0x50,0x57,0xe4,0x31,0xc0,
  0x79,0x5e,0xc9,0x4,0xe5,0x95,0x1,0x40,0x41,0x13,0x15,0x4e,0x66,0x80,0xa8,0x11,
  0x58,0x1,0xff,0xc5,0x6c,0x9b,0xde,0xfe,0xc4,0x62,0x41,0xbb,0xe7,0xa3,0x2d,0x1,
  0xf0,0xe5,0x3c,0x8a,0x55,0xf,0x76,0x16,0x42,0x2c,0xde,0x84,0xfa,0xd5,0x5c,0x75,
  0xe1,0xdf,0x0,0xbe,0x32,0x7a,0xdd,0x3b,0x79,0xd4,0xac,0x52,0x68,0x3c,0x78,0x13,
  0xd9,0x1d,0xa,0x73,0xe0,0x24,0x2c,0x6a,0x59,0xa,0xda,0x1,0x42,0xfb,0x96,0x1e,
  0xbf,0x36,0x2d,0xf2,0xa,0xed,0x9e,0x59,0xf3,0xeb,0x80,0x14,0x12,0x0,0x25,0x88,
  0x55,0x46,0x9b,0x11,0x24,0x0,0xaa,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kolf
  0x0,0x4,
  0x0,0x7,0x26,0x26,
  0x0,0x6b,
  0x0,0x6f,0x0,0x6c,0x0,0x66,
    // kolfui.rc
  0x0,0x9,
  0x2,0xdb,0x61,0x43,
  0x0,0x6b,
  0x0,0x6f,0x0,0x6c,0x0,0x66,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9e,0x91,0xb9,0x17,0x58,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9e,0x91,0xb9,0x17,0x58,
  // :/kxmlgui5/kolf
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9e,0x91,0xb9,0x17,0x58,
  // :/kxmlgui5/kolf/kolfui.rc
  0x0,0x0,0x0,0x24,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9e,0x91,0xb9,0x17,0x58,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kolf)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kolf)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kolf)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kolf)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kolf)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kolf)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
