/****************************************************************************
** Meta object code from reading C++ file 'landscape.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kolf-26.04.2/src/landscape.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'landscape.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Kolf13LandscapeItemE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::LandscapeItem::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf13LandscapeItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::LandscapeItem",
        "setBlinkEnabled",
        "",
        "blinkEnabled",
        "setBlinkInterval",
        "blinkInterval"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setBlinkEnabled'
        QtMocHelpers::SlotData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'setBlinkInterval'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LandscapeItem, qt_meta_tag_ZN4Kolf13LandscapeItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::LandscapeItem::staticMetaObject = { {
    QMetaObject::SuperData::link<EllipticalCanvasItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf13LandscapeItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf13LandscapeItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf13LandscapeItemE_t>.metaTypes,
    nullptr
} };

void Kolf::LandscapeItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LandscapeItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setBlinkEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->setBlinkInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::LandscapeItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::LandscapeItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf13LandscapeItemE_t>.strings))
        return static_cast<void*>(this);
    return EllipticalCanvasItem::qt_metacast(_clname);
}

int Kolf::LandscapeItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EllipticalCanvasItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Kolf16LandscapeOverlayE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::LandscapeOverlay::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf16LandscapeOverlayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::LandscapeOverlay",
        "moveHandle",
        "",
        "QPointF",
        "handleScenePos"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'moveHandle'
        QtMocHelpers::SlotData<void(const QPointF &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LandscapeOverlay, qt_meta_tag_ZN4Kolf16LandscapeOverlayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::LandscapeOverlay::staticMetaObject = { {
    QMetaObject::SuperData::link<Kolf::Overlay::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf16LandscapeOverlayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf16LandscapeOverlayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf16LandscapeOverlayE_t>.metaTypes,
    nullptr
} };

void Kolf::LandscapeOverlay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LandscapeOverlay *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->moveHandle((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::LandscapeOverlay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::LandscapeOverlay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf16LandscapeOverlayE_t>.strings))
        return static_cast<void*>(this);
    return Kolf::Overlay::qt_metacast(_clname);
}

int Kolf::LandscapeOverlay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kolf::Overlay::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Kolf15LandscapeConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::LandscapeConfig::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf15LandscapeConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::LandscapeConfig",
        "blinkIntervalChanged",
        "",
        "blinkInterval",
        "setBlinkInterval",
        "sliderValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'blinkIntervalChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setBlinkInterval'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LandscapeConfig, qt_meta_tag_ZN4Kolf15LandscapeConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::LandscapeConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<Config::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf15LandscapeConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf15LandscapeConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf15LandscapeConfigE_t>.metaTypes,
    nullptr
} };

void Kolf::LandscapeConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LandscapeConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->blinkIntervalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->setBlinkInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LandscapeConfig::*)(int )>(_a, &LandscapeConfig::blinkIntervalChanged, 0))
            return;
    }
}

const QMetaObject *Kolf::LandscapeConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::LandscapeConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf15LandscapeConfigE_t>.strings))
        return static_cast<void*>(this);
    return Config::qt_metacast(_clname);
}

int Kolf::LandscapeConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Config::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Kolf::LandscapeConfig::blinkIntervalChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN4Kolf5SlopeE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::Slope::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf5SlopeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::Slope",
        "setGrade",
        "",
        "grade",
        "setReversed",
        "reversed",
        "setSlopeType",
        "type",
        "setStuckOnGround",
        "stuckOnGround"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setGrade'
        QtMocHelpers::SlotData<void(double)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Slot 'setReversed'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setSlopeType'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setStuckOnGround'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Slope, qt_meta_tag_ZN4Kolf5SlopeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::Slope::staticMetaObject = { {
    QMetaObject::SuperData::link<Tagaro::SpriteObjectItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf5SlopeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf5SlopeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf5SlopeE_t>.metaTypes,
    nullptr
} };

void Kolf::Slope::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Slope *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setGrade((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 1: _t->setReversed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->setSlopeType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->setStuckOnGround((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::Slope::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::Slope::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf5SlopeE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "CanvasItem"))
        return static_cast< CanvasItem*>(this);
    return Tagaro::SpriteObjectItem::qt_metacast(_clname);
}

int Kolf::Slope::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Tagaro::SpriteObjectItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Kolf12SlopeOverlayE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::SlopeOverlay::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf12SlopeOverlayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::SlopeOverlay",
        "moveHandle",
        "",
        "QPointF",
        "handleScenePos"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'moveHandle'
        QtMocHelpers::SlotData<void(const QPointF &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SlopeOverlay, qt_meta_tag_ZN4Kolf12SlopeOverlayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::SlopeOverlay::staticMetaObject = { {
    QMetaObject::SuperData::link<Kolf::Overlay::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf12SlopeOverlayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf12SlopeOverlayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf12SlopeOverlayE_t>.metaTypes,
    nullptr
} };

void Kolf::SlopeOverlay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SlopeOverlay *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->moveHandle((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::SlopeOverlay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::SlopeOverlay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf12SlopeOverlayE_t>.strings))
        return static_cast<void*>(this);
    return Kolf::Overlay::qt_metacast(_clname);
}

int Kolf::SlopeOverlay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kolf::Overlay::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
