/****************************************************************************
** Meta object code from reading C++ file 'kolf.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kolf-26.04.2/src/kolf.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kolf.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KolfWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KolfWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10KolfWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KolfWindow",
        "closeGame",
        "",
        "updateModified",
        "startNewGame",
        "loadGame",
        "tutorial",
        "newGame",
        "save",
        "saveAs",
        "saveGame",
        "saveGameAs",
        "newPlayersTurn",
        "Player*",
        "gameOver",
        "editingStarted",
        "editingEnded",
        "checkEditing",
        "setHoleFocus",
        "inPlayStart",
        "inPlayEnd",
        "maxStrokesReached",
        "updateHoleMenu",
        "titleChanged",
        "newStatusText",
        "showInfoChanged",
        "useMouseChanged",
        "useAdvancedPuttingChanged",
        "showGuideLineChanged",
        "soundChanged",
        "showHighScores",
        "enableAllMessages",
        "createSpacer",
        "emptySlot",
        "setCurrentHole"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'closeGame'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateModified'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'startNewGame'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'loadGame'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'tutorial'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'newGame'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'saveGame'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'saveGameAs'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'newPlayersTurn'
        QtMocHelpers::SlotData<void(Player *)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'gameOver'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'editingStarted'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'editingEnded'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'checkEditing'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'setHoleFocus'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'inPlayStart'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'inPlayEnd'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'maxStrokesReached'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'updateHoleMenu'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'titleChanged'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'newStatusText'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'showInfoChanged'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'useMouseChanged'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'useAdvancedPuttingChanged'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showGuideLineChanged'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'soundChanged'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showHighScores'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'enableAllMessages'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'createSpacer'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'emptySlot'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'setCurrentHole'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KolfWindow, qt_meta_tag_ZN10KolfWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KolfWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KolfWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KolfWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KolfWindowE_t>.metaTypes,
    nullptr
} };

void KolfWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KolfWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->closeGame(); break;
        case 1: _t->updateModified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->startNewGame(); break;
        case 3: _t->loadGame(); break;
        case 4: _t->tutorial(); break;
        case 5: _t->newGame(); break;
        case 6: _t->save(); break;
        case 7: _t->saveAs(); break;
        case 8: _t->saveGame(); break;
        case 9: _t->saveGameAs(); break;
        case 10: _t->newPlayersTurn((*reinterpret_cast<std::add_pointer_t<Player*>>(_a[1]))); break;
        case 11: _t->gameOver(); break;
        case 12: _t->editingStarted(); break;
        case 13: _t->editingEnded(); break;
        case 14: _t->checkEditing(); break;
        case 15: _t->setHoleFocus(); break;
        case 16: _t->inPlayStart(); break;
        case 17: _t->inPlayEnd(); break;
        case 18: _t->maxStrokesReached((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->updateHoleMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->newStatusText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->showInfoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->useMouseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->useAdvancedPuttingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->showGuideLineChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->soundChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->showHighScores(); break;
        case 28: _t->enableAllMessages(); break;
        case 29: _t->createSpacer(); break;
        case 30: _t->emptySlot(); break;
        case 31: _t->setCurrentHole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KolfWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KolfWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KolfWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KolfWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}
QT_WARNING_POP
