/****************************************************************************
** Meta object code from reading C++ file 'obstacles.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kolf-26.04.2/src/obstacles.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'obstacles.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Kolf6BumperE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::Bumper::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf6BumperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::Bumper",
        "turnBumperOff",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'turnBumperOff'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Bumper, qt_meta_tag_ZN4Kolf6BumperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::Bumper::staticMetaObject = { {
    QMetaObject::SuperData::link<EllipticalCanvasItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf6BumperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf6BumperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf6BumperE_t>.metaTypes,
    nullptr
} };

void Kolf::Bumper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Bumper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->turnBumperOff(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Kolf::Bumper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::Bumper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf6BumperE_t>.strings))
        return static_cast<void*>(this);
    return EllipticalCanvasItem::qt_metacast(_clname);
}

int Kolf::Bumper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EllipticalCanvasItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Kolf11WallOverlayE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::WallOverlay::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf11WallOverlayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::WallOverlay",
        "moveHandle",
        "",
        "QPointF",
        "handleScenePos"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'moveHandle'
        QtMocHelpers::SlotData<void(const QPointF &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WallOverlay, qt_meta_tag_ZN4Kolf11WallOverlayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::WallOverlay::staticMetaObject = { {
    QMetaObject::SuperData::link<Kolf::Overlay::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf11WallOverlayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf11WallOverlayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf11WallOverlayE_t>.metaTypes,
    nullptr
} };

void Kolf::WallOverlay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WallOverlay *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->moveHandle((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::WallOverlay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::WallOverlay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf11WallOverlayE_t>.strings))
        return static_cast<void*>(this);
    return Kolf::Overlay::qt_metacast(_clname);
}

int Kolf::WallOverlay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kolf::Overlay::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Kolf13RectangleItemE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::RectangleItem::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf13RectangleItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::RectangleItem",
        "wallChanged",
        "",
        "Kolf::WallIndex",
        "index",
        "hasWall",
        "wallAllowed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wallChanged'
        QtMocHelpers::SignalData<void(Kolf::WallIndex, bool, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 }, { QMetaType::Bool, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RectangleItem, qt_meta_tag_ZN4Kolf13RectangleItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::RectangleItem::staticMetaObject = { {
    QMetaObject::SuperData::link<Tagaro::SpriteObjectItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf13RectangleItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf13RectangleItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf13RectangleItemE_t>.metaTypes,
    nullptr
} };

void Kolf::RectangleItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RectangleItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wallChanged((*reinterpret_cast<std::add_pointer_t<Kolf::WallIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RectangleItem::*)(Kolf::WallIndex , bool , bool )>(_a, &RectangleItem::wallChanged, 0))
            return;
    }
}

const QMetaObject *Kolf::RectangleItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::RectangleItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf13RectangleItemE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "CanvasItem"))
        return static_cast< CanvasItem*>(this);
    return Tagaro::SpriteObjectItem::qt_metacast(_clname);
}

int Kolf::RectangleItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Tagaro::SpriteObjectItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Kolf::RectangleItem::wallChanged(Kolf::WallIndex _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}
namespace {
struct qt_meta_tag_ZN4Kolf16RectangleOverlayE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::RectangleOverlay::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf16RectangleOverlayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::RectangleOverlay",
        "moveHandle",
        "",
        "QPointF",
        "handleScenePos"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'moveHandle'
        QtMocHelpers::SlotData<void(const QPointF &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RectangleOverlay, qt_meta_tag_ZN4Kolf16RectangleOverlayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::RectangleOverlay::staticMetaObject = { {
    QMetaObject::SuperData::link<Kolf::Overlay::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf16RectangleOverlayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf16RectangleOverlayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf16RectangleOverlayE_t>.metaTypes,
    nullptr
} };

void Kolf::RectangleOverlay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RectangleOverlay *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->moveHandle((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::RectangleOverlay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::RectangleOverlay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf16RectangleOverlayE_t>.strings))
        return static_cast<void*>(this);
    return Kolf::Overlay::qt_metacast(_clname);
}

int Kolf::RectangleOverlay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kolf::Overlay::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Kolf15RectangleConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::RectangleConfig::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf15RectangleConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::RectangleConfig",
        "setWall",
        "",
        "hasWall",
        "wallChanged",
        "Kolf::WallIndex",
        "index",
        "wallAllowed"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setWall'
        QtMocHelpers::SlotData<void(bool)>(1, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'wallChanged'
        QtMocHelpers::SlotData<void(Kolf::WallIndex, bool, bool)>(4, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Bool, 3 }, { QMetaType::Bool, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RectangleConfig, qt_meta_tag_ZN4Kolf15RectangleConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::RectangleConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<Config::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf15RectangleConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf15RectangleConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf15RectangleConfigE_t>.metaTypes,
    nullptr
} };

void Kolf::RectangleConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RectangleConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setWall((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->wallChanged((*reinterpret_cast<std::add_pointer_t<Kolf::WallIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::RectangleConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::RectangleConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf15RectangleConfigE_t>.strings))
        return static_cast<void*>(this);
    return Config::qt_metacast(_clname);
}

int Kolf::RectangleConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Config::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Kolf7FloaterE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::Floater::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf7FloaterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::Floater",
        "setSpeed",
        "",
        "speed"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setSpeed'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Floater, qt_meta_tag_ZN4Kolf7FloaterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::Floater::staticMetaObject = { {
    QMetaObject::SuperData::link<Kolf::RectangleItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf7FloaterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf7FloaterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf7FloaterE_t>.metaTypes,
    nullptr
} };

void Kolf::Floater::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Floater *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setSpeed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::Floater::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::Floater::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf7FloaterE_t>.strings))
        return static_cast<void*>(this);
    return Kolf::RectangleItem::qt_metacast(_clname);
}

int Kolf::Floater::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kolf::RectangleItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Kolf14FloaterOverlayE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::FloaterOverlay::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf14FloaterOverlayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::FloaterOverlay",
        "moveMotionLineHandle",
        "",
        "QPointF",
        "handleScenePos"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'moveMotionLineHandle'
        QtMocHelpers::SlotData<void(const QPointF &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FloaterOverlay, qt_meta_tag_ZN4Kolf14FloaterOverlayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::FloaterOverlay::staticMetaObject = { {
    QMetaObject::SuperData::link<Kolf::RectangleOverlay::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf14FloaterOverlayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf14FloaterOverlayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf14FloaterOverlayE_t>.metaTypes,
    nullptr
} };

void Kolf::FloaterOverlay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FloaterOverlay *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->moveMotionLineHandle((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::FloaterOverlay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::FloaterOverlay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf14FloaterOverlayE_t>.strings))
        return static_cast<void*>(this);
    return Kolf::RectangleOverlay::qt_metacast(_clname);
}

int Kolf::FloaterOverlay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kolf::RectangleOverlay::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Kolf4SignE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::Sign::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf4SignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::Sign",
        "setText",
        "",
        "text"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setText'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Sign, qt_meta_tag_ZN4Kolf4SignE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::Sign::staticMetaObject = { {
    QMetaObject::SuperData::link<Kolf::RectangleItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf4SignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf4SignE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf4SignE_t>.metaTypes,
    nullptr
} };

void Kolf::Sign::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Sign *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::Sign::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::Sign::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf4SignE_t>.strings))
        return static_cast<void*>(this);
    return Kolf::RectangleItem::qt_metacast(_clname);
}

int Kolf::Sign::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kolf::RectangleItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4Kolf8WindmillE_t {};
} // unnamed namespace

template <> constexpr inline auto Kolf::Windmill::qt_create_metaobjectdata<qt_meta_tag_ZN4Kolf8WindmillE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kolf::Windmill",
        "setGuardAtTop",
        "",
        "guardAtTop",
        "setSpeed",
        "speed"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setGuardAtTop'
        QtMocHelpers::SlotData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'setSpeed'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Windmill, qt_meta_tag_ZN4Kolf8WindmillE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kolf::Windmill::staticMetaObject = { {
    QMetaObject::SuperData::link<Kolf::RectangleItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf8WindmillE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf8WindmillE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kolf8WindmillE_t>.metaTypes,
    nullptr
} };

void Kolf::Windmill::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Windmill *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setGuardAtTop((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->setSpeed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kolf::Windmill::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kolf::Windmill::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kolf8WindmillE_t>.strings))
        return static_cast<void*>(this);
    return Kolf::RectangleItem::qt_metacast(_clname);
}

int Kolf::Windmill::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Kolf::RectangleItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
