/****************************************************************************
** Meta object code from reading C++ file 'game.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kolf-26.04.2/src/game.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'game.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10HoleConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto HoleConfig::qt_create_metaobjectdata<qt_meta_tag_ZN10HoleConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HoleConfig",
        "authorChanged",
        "",
        "parChanged",
        "maxStrokesChanged",
        "nameChanged",
        "borderWallsChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'authorChanged'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'parChanged'
        QtMocHelpers::SlotData<void(int)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'maxStrokesChanged'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'nameChanged'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'borderWallsChanged'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HoleConfig, qt_meta_tag_ZN10HoleConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject HoleConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<Config::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10HoleConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10HoleConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10HoleConfigE_t>.metaTypes,
    nullptr
} };

void HoleConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HoleConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->authorChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->parChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->maxStrokesChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->borderWallsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *HoleConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HoleConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10HoleConfigE_t>.strings))
        return static_cast<void*>(this);
    return Config::qt_metacast(_clname);
}

int HoleConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Config::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KolfGameE_t {};
} // unnamed namespace

template <> constexpr inline auto KolfGame::qt_create_metaobjectdata<qt_meta_tag_ZN8KolfGameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KolfGame",
        "holesDone",
        "",
        "newHole",
        "parChanged",
        "titleChanged",
        "largestHole",
        "scoreChanged",
        "newPlayersTurn",
        "Player*",
        "newSelectedItem",
        "CanvasItem*",
        "checkEditing",
        "editingStarted",
        "editingEnded",
        "inPlayStart",
        "inPlayEnd",
        "maxStrokesReached",
        "currentHole",
        "modifiedChanged",
        "newStatusText",
        "pause",
        "unPause",
        "save",
        "toggleEditMode",
        "setModified",
        "mod",
        "addNewObject",
        "identifier",
        "addNewHole",
        "switchHole",
        "nextHole",
        "prevHole",
        "firstHole",
        "lastHole",
        "randHole",
        "showInfoDlg",
        "resetHole",
        "clearHole",
        "setShowInfo",
        "yes",
        "toggleShowInfo",
        "updateShowInfo",
        "setUseMouse",
        "setUseAdvancedPutting",
        "setShowGuideLine",
        "setSound",
        "undoShot",
        "timeout",
        "saveScores",
        "KConfig*",
        "startFirstHole",
        "hole",
        "sayWhosGoing",
        "shotDone",
        "holeDone",
        "startNextHole",
        "fastTimeout",
        "putterTimeout",
        "autoSaveTimeout",
        "emitMax"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'holesDone'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newHole'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'parChanged'
        QtMocHelpers::SignalData<void(int, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'largestHole'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'scoreChanged'
        QtMocHelpers::SignalData<void(int, int, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'newPlayersTurn'
        QtMocHelpers::SignalData<void(Player *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'newSelectedItem'
        QtMocHelpers::SignalData<void(CanvasItem *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'checkEditing'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editingStarted'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editingEnded'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inPlayStart'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inPlayEnd'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxStrokesReached'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'currentHole'
        QtMocHelpers::SignalData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'modifiedChanged'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'newStatusText'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unPause'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleEditMode'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setModified'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setModified'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'addNewObject'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'addNewHole'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchHole'
        QtMocHelpers::SlotData<void(int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'switchHole'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'nextHole'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'prevHole'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'firstHole'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'lastHole'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'randHole'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showInfoDlg'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showInfoDlg'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'resetHole'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearHole'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setShowInfo'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'toggleShowInfo'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateShowInfo'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setUseMouse'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setUseAdvancedPutting'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setShowGuideLine'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setSound'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'undoShot'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'timeout'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveScores'
        QtMocHelpers::SlotData<void(KConfig *)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 2 },
        }}),
        // Slot 'startFirstHole'
        QtMocHelpers::SlotData<void(int)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 52 },
        }}),
        // Slot 'sayWhosGoing'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shotDone'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'holeDone'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startNextHole'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fastTimeout'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'putterTimeout'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'autoSaveTimeout'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitMax'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KolfGame, qt_meta_tag_ZN8KolfGameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KolfGame::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KolfGameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KolfGameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KolfGameE_t>.metaTypes,
    nullptr
} };

void KolfGame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KolfGame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->holesDone(); break;
        case 1: _t->newHole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->parChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->largestHole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->scoreChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->newPlayersTurn((*reinterpret_cast<std::add_pointer_t<Player*>>(_a[1]))); break;
        case 7: _t->newSelectedItem((*reinterpret_cast<std::add_pointer_t<CanvasItem*>>(_a[1]))); break;
        case 8: _t->checkEditing(); break;
        case 9: _t->editingStarted(); break;
        case 10: _t->editingEnded(); break;
        case 11: _t->inPlayStart(); break;
        case 12: _t->inPlayEnd(); break;
        case 13: _t->maxStrokesReached((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->currentHole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->modifiedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->newStatusText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->pause(); break;
        case 18: _t->unPause(); break;
        case 19: _t->save(); break;
        case 20: _t->toggleEditMode(); break;
        case 21: _t->setModified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->setModified(); break;
        case 23: _t->addNewObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->addNewHole(); break;
        case 25: _t->switchHole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->switchHole((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->nextHole(); break;
        case 28: _t->prevHole(); break;
        case 29: _t->firstHole(); break;
        case 30: _t->lastHole(); break;
        case 31: _t->randHole(); break;
        case 32: _t->showInfoDlg((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->showInfoDlg(); break;
        case 34: _t->resetHole(); break;
        case 35: _t->clearHole(); break;
        case 36: _t->setShowInfo((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->toggleShowInfo(); break;
        case 38: _t->updateShowInfo(); break;
        case 39: _t->setUseMouse((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->setUseAdvancedPutting((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->setShowGuideLine((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->setSound((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->undoShot(); break;
        case 44: _t->timeout(); break;
        case 45: _t->saveScores((*reinterpret_cast<std::add_pointer_t<KConfig*>>(_a[1]))); break;
        case 46: _t->startFirstHole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: _t->sayWhosGoing(); break;
        case 48: _t->shotDone(); break;
        case 49: _t->holeDone(); break;
        case 50: _t->startNextHole(); break;
        case 51: _t->fastTimeout(); break;
        case 52: _t->putterTimeout(); break;
        case 53: _t->autoSaveTimeout(); break;
        case 54: _t->emitMax(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)()>(_a, &KolfGame::holesDone, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(int )>(_a, &KolfGame::newHole, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(int , int )>(_a, &KolfGame::parChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(const QString & )>(_a, &KolfGame::titleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(int )>(_a, &KolfGame::largestHole, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(int , int , int )>(_a, &KolfGame::scoreChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(Player * )>(_a, &KolfGame::newPlayersTurn, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(CanvasItem * )>(_a, &KolfGame::newSelectedItem, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)()>(_a, &KolfGame::checkEditing, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)()>(_a, &KolfGame::editingStarted, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)()>(_a, &KolfGame::editingEnded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)()>(_a, &KolfGame::inPlayStart, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)()>(_a, &KolfGame::inPlayEnd, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(const QString & )>(_a, &KolfGame::maxStrokesReached, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(int )>(_a, &KolfGame::currentHole, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(bool )>(_a, &KolfGame::modifiedChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (KolfGame::*)(const QString & )>(_a, &KolfGame::newStatusText, 16))
            return;
    }
}

const QMetaObject *KolfGame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KolfGame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KolfGameE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int KolfGame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 55)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 55)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 55;
    }
    return _id;
}

// SIGNAL 0
void KolfGame::holesDone()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KolfGame::newHole(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KolfGame::parChanged(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KolfGame::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KolfGame::largestHole(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KolfGame::scoreChanged(int _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void KolfGame::newPlayersTurn(Player * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KolfGame::newSelectedItem(CanvasItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KolfGame::checkEditing()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KolfGame::editingStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KolfGame::editingEnded()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KolfGame::inPlayStart()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KolfGame::inPlayEnd()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KolfGame::maxStrokesReached(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void KolfGame::currentHole(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void KolfGame::modifiedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void KolfGame::newStatusText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}
QT_WARNING_POP
